@@ -33,7 +33,7 @@ testthat::test_that("plotSpatialOverlay prints",{
     expect_error(gp <- plotSpatialOverlay(overlay, colorBy = "Segment_type", 
                                           hiRes = F, scaleBar = F), NA)
     expect_error(gp, NA)
-    expect_true(all(class(gp) == c("gg","ggplot")))
+    expect_true(is_ggplot(gp))
     
     #Spec 6. The function produces reproducible figures.
     vdiffr::expect_doppelganger("lowRes no scaleBar", gp)
@@ -41,7 +41,7 @@ testthat::test_that("plotSpatialOverlay prints",{
     expect_error(gp <- plotSpatialOverlay(overlay, colorBy = "Segment_type", 
                                       hiRes = T, scaleBar = F), NA)
     expect_error(gp, NA)
-    expect_true(all(class(gp) == c("gg","ggplot")))
+    expect_true(is_ggplot(gp))
     
     #Spec 6. The function produces reproducible figures.
     #resulting image is too large 
@@ -80,7 +80,7 @@ testthat::test_that("plotSpatialOverlay prints",{
     expect_error(gp <- plotSpatialOverlay(overlay, colorBy = "Segment_type", 
                                           scaleBar = F), NA)
     expect_error(gp, NA)
-    expect_true(all(class(gp) == c("gg","ggplot")))
+    expect_true(is_ggplot(gp))
     
     #Spec 6. The function produces reproducible figures.
     #resulting image too large
@@ -298,7 +298,7 @@ testthat::test_that("plotting occurs on images",{
                                           scaleBar = FALSE, 
                                           image = TRUE), NA)
     expect_error(gp4, NA)
-    expect_true(all(class(gp4) == c("gg","ggplot")))
+    expect_true(is_ggplot(gp4))
     
     #Spec 6. The function produces reproducible figures.
     #resulting image too large
@@ -310,7 +310,7 @@ testthat::test_that("plotting occurs on images",{
                                           scaleBar = FALSE, 
                                           image = TRUE), NA)
     expect_error(gp, NA)
-    expect_true(all(class(gp) == c("gg","ggplot")))
+    expect_true(is_ggplot(gp))
     
     #Spec 6. The function produces reproducible figures.
     #resulting image too large
